window.Gleam.initSearch([{"doc":"sketch_redraw","title":"sketch_redraw","content":"# Sketch Redraw\n\n&gt; In case you&#39;re here and don&#39;t know Sketch, take a look at\n&gt; [`sketch` package](https://hexdocs.pm/sketch)!\n\n&gt; This readme is a carbon-copy of the Sketch Redraw section in `sketch` readme.\n\n## Setup\n\nWhen you&#39;re using Redraw, `sketch_redraw` covers you. `sketch_redraw` exposes\none entrypoint, `sketch/redraw`, containing everything needed to get started.\n\n```gleam\n// main.gleam\nimport redraw\nimport sketch\nimport sketch/redraw as sketch_redraw\n\npub fn main() {\n  let root = client.create_root(&quot;root&quot;)\n  client.render(root, redraw.strict_mode([\n    // Initialise the cache. Sketch Redraw handles the details for you.\n    sr.provider([\n      // Here comes your components!\n    ])\n  ]))\n}\n```\n\n## Usage\n\n`sketch_redraw` exposes one module to help you build your site, similarly to\nredraw: `sketch/redraw/html`. `html` is simply a supercharged component,\naccepting a `sketch.Class` as first argument, and applies that style to the\nnode. Because it&#39;s a simple component, `sketch/redraw/html` and `redraw/html`\ncan be mixed in the same code without issue! Because of that property,\n`sketch_redraw` _does not_ expose `text` and `none` function at that time.\n\n```gleam\nimport redraw/html as h\nimport sketch\nimport sketch/redraw/html\nimport sketch/size.{px}\n\nfn main_style() {\n  sketch.class([\n    sketch.background(&quot;red&quot;),\n    sketch.font_size(px(16)),\n  ])\n}\n\nfn view(model: Int) {\n  html.div(main_style(), [], [\n    h.div([], [\n      h.text(int.to_string(model))\n    ]),\n  ])\n}\n```\n\nAnd you&#39;re done! Enjoy your Redraw app, Sketch-enhanced!\n\n## Final notes\n\nSketch Redraw tries to integrate nicely with React Devtools! In case you&#39;re\nseeing something weird, signal the bug!\n","url":"index.html"},{"doc":"sketch/redraw","title":"provider","content":"pub fn provider(children: List(Component)) -&gt; Component\n Create the Sketch provider used to manage `Cache`. This makes sure identical\n styles will never be computed twice.\n\n Use it at root of your render function.\n\n \n import redraw\n import redraw_dom/client\n import sketch/redraw as sketch_redraw\n\n pub fn main() {\n   let app = app()\n   let root = client.create_root(&quot;root&quot;)\n   client.render(root, {\n     redraw.strict_mode([\n       sketch_redraw.provider([\n         app(),\n       ]),\n     ])\n   })\n }\n \nSynonyms:\nsketch/redraw.provider\nsketch/redraw provider","url":"sketch/redraw.html#provider"},{"doc":"sketch/redraw","title":"sketch/redraw","content":"","url":"sketch/redraw.html"},{"doc":"sketch/redraw/html","title":"a","content":"pub fn a(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.a\nsketch/redraw/html a","url":"sketch/redraw/html.html#a"},{"doc":"sketch/redraw/html","title":"abbr","content":"pub fn abbr(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.abbr\nsketch/redraw/html abbr","url":"sketch/redraw/html.html#abbr"},{"doc":"sketch/redraw/html","title":"address","content":"pub fn address(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.address\nsketch/redraw/html address","url":"sketch/redraw/html.html#address"},{"doc":"sketch/redraw/html","title":"area","content":"pub fn area(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.area\nsketch/redraw/html area","url":"sketch/redraw/html.html#area"},{"doc":"sketch/redraw/html","title":"article","content":"pub fn article(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.article\nsketch/redraw/html article","url":"sketch/redraw/html.html#article"},{"doc":"sketch/redraw/html","title":"aside","content":"pub fn aside(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.aside\nsketch/redraw/html aside","url":"sketch/redraw/html.html#aside"},{"doc":"sketch/redraw/html","title":"audio","content":"pub fn audio(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.audio\nsketch/redraw/html audio","url":"sketch/redraw/html.html#audio"},{"doc":"sketch/redraw/html","title":"b","content":"pub fn b(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.b\nsketch/redraw/html b","url":"sketch/redraw/html.html#b"},{"doc":"sketch/redraw/html","title":"base","content":"pub fn base(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.base\nsketch/redraw/html base","url":"sketch/redraw/html.html#base"},{"doc":"sketch/redraw/html","title":"bdi","content":"pub fn bdi(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.bdi\nsketch/redraw/html bdi","url":"sketch/redraw/html.html#bdi"},{"doc":"sketch/redraw/html","title":"bdo","content":"pub fn bdo(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.bdo\nsketch/redraw/html bdo","url":"sketch/redraw/html.html#bdo"},{"doc":"sketch/redraw/html","title":"blockquote","content":"pub fn blockquote(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.blockquote\nsketch/redraw/html blockquote","url":"sketch/redraw/html.html#blockquote"},{"doc":"sketch/redraw/html","title":"body","content":"pub fn body(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.body\nsketch/redraw/html body","url":"sketch/redraw/html.html#body"},{"doc":"sketch/redraw/html","title":"br","content":"pub fn br(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.br\nsketch/redraw/html br","url":"sketch/redraw/html.html#br"},{"doc":"sketch/redraw/html","title":"button","content":"pub fn button(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.button\nsketch/redraw/html button","url":"sketch/redraw/html.html#button"},{"doc":"sketch/redraw/html","title":"canvas","content":"pub fn canvas(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.canvas\nsketch/redraw/html canvas","url":"sketch/redraw/html.html#canvas"},{"doc":"sketch/redraw/html","title":"caption","content":"pub fn caption(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.caption\nsketch/redraw/html caption","url":"sketch/redraw/html.html#caption"},{"doc":"sketch/redraw/html","title":"cite","content":"pub fn cite(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.cite\nsketch/redraw/html cite","url":"sketch/redraw/html.html#cite"},{"doc":"sketch/redraw/html","title":"code","content":"pub fn code(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.code\nsketch/redraw/html code","url":"sketch/redraw/html.html#code"},{"doc":"sketch/redraw/html","title":"col","content":"pub fn col(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.col\nsketch/redraw/html col","url":"sketch/redraw/html.html#col"},{"doc":"sketch/redraw/html","title":"colgroup","content":"pub fn colgroup(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.colgroup\nsketch/redraw/html colgroup","url":"sketch/redraw/html.html#colgroup"},{"doc":"sketch/redraw/html","title":"data","content":"pub fn data(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.data\nsketch/redraw/html data","url":"sketch/redraw/html.html#data"},{"doc":"sketch/redraw/html","title":"datalist","content":"pub fn datalist(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.datalist\nsketch/redraw/html datalist","url":"sketch/redraw/html.html#datalist"},{"doc":"sketch/redraw/html","title":"dd","content":"pub fn dd(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.dd\nsketch/redraw/html dd","url":"sketch/redraw/html.html#dd"},{"doc":"sketch/redraw/html","title":"del","content":"pub fn del(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.del\nsketch/redraw/html del","url":"sketch/redraw/html.html#del"},{"doc":"sketch/redraw/html","title":"details","content":"pub fn details(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.details\nsketch/redraw/html details","url":"sketch/redraw/html.html#details"},{"doc":"sketch/redraw/html","title":"dfn","content":"pub fn dfn(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.dfn\nsketch/redraw/html dfn","url":"sketch/redraw/html.html#dfn"},{"doc":"sketch/redraw/html","title":"dialog","content":"pub fn dialog(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.dialog\nsketch/redraw/html dialog","url":"sketch/redraw/html.html#dialog"},{"doc":"sketch/redraw/html","title":"div","content":"pub fn div(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.div\nsketch/redraw/html div","url":"sketch/redraw/html.html#div"},{"doc":"sketch/redraw/html","title":"dl","content":"pub fn dl(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.dl\nsketch/redraw/html dl","url":"sketch/redraw/html.html#dl"},{"doc":"sketch/redraw/html","title":"dt","content":"pub fn dt(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.dt\nsketch/redraw/html dt","url":"sketch/redraw/html.html#dt"},{"doc":"sketch/redraw/html","title":"em","content":"pub fn em(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.em\nsketch/redraw/html em","url":"sketch/redraw/html.html#em"},{"doc":"sketch/redraw/html","title":"embed","content":"pub fn embed(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.embed\nsketch/redraw/html embed","url":"sketch/redraw/html.html#embed"},{"doc":"sketch/redraw/html","title":"fieldset","content":"pub fn fieldset(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.fieldset\nsketch/redraw/html fieldset","url":"sketch/redraw/html.html#fieldset"},{"doc":"sketch/redraw/html","title":"figcaption","content":"pub fn figcaption(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.figcaption\nsketch/redraw/html figcaption","url":"sketch/redraw/html.html#figcaption"},{"doc":"sketch/redraw/html","title":"figure","content":"pub fn figure(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.figure\nsketch/redraw/html figure","url":"sketch/redraw/html.html#figure"},{"doc":"sketch/redraw/html","title":"footer","content":"pub fn footer(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.footer\nsketch/redraw/html footer","url":"sketch/redraw/html.html#footer"},{"doc":"sketch/redraw/html","title":"form","content":"pub fn form(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.form\nsketch/redraw/html form","url":"sketch/redraw/html.html#form"},{"doc":"sketch/redraw/html","title":"h1","content":"pub fn h1(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.h1\nsketch/redraw/html h1","url":"sketch/redraw/html.html#h1"},{"doc":"sketch/redraw/html","title":"h2","content":"pub fn h2(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.h2\nsketch/redraw/html h2","url":"sketch/redraw/html.html#h2"},{"doc":"sketch/redraw/html","title":"h3","content":"pub fn h3(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.h3\nsketch/redraw/html h3","url":"sketch/redraw/html.html#h3"},{"doc":"sketch/redraw/html","title":"h4","content":"pub fn h4(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.h4\nsketch/redraw/html h4","url":"sketch/redraw/html.html#h4"},{"doc":"sketch/redraw/html","title":"h5","content":"pub fn h5(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.h5\nsketch/redraw/html h5","url":"sketch/redraw/html.html#h5"},{"doc":"sketch/redraw/html","title":"h6","content":"pub fn h6(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.h6\nsketch/redraw/html h6","url":"sketch/redraw/html.html#h6"},{"doc":"sketch/redraw/html","title":"head","content":"pub fn head(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.head\nsketch/redraw/html head","url":"sketch/redraw/html.html#head"},{"doc":"sketch/redraw/html","title":"header","content":"pub fn header(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.header\nsketch/redraw/html header","url":"sketch/redraw/html.html#header"},{"doc":"sketch/redraw/html","title":"hgroup","content":"pub fn hgroup(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.hgroup\nsketch/redraw/html hgroup","url":"sketch/redraw/html.html#hgroup"},{"doc":"sketch/redraw/html","title":"hr","content":"pub fn hr(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.hr\nsketch/redraw/html hr","url":"sketch/redraw/html.html#hr"},{"doc":"sketch/redraw/html","title":"html","content":"pub fn html(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.html\nsketch/redraw/html html","url":"sketch/redraw/html.html#html"},{"doc":"sketch/redraw/html","title":"i","content":"pub fn i(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.i\nsketch/redraw/html i","url":"sketch/redraw/html.html#i"},{"doc":"sketch/redraw/html","title":"iframe","content":"pub fn iframe(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.iframe\nsketch/redraw/html iframe","url":"sketch/redraw/html.html#iframe"},{"doc":"sketch/redraw/html","title":"img","content":"pub fn img(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.img\nsketch/redraw/html img","url":"sketch/redraw/html.html#img"},{"doc":"sketch/redraw/html","title":"input","content":"pub fn input(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.input\nsketch/redraw/html input","url":"sketch/redraw/html.html#input"},{"doc":"sketch/redraw/html","title":"ins","content":"pub fn ins(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.ins\nsketch/redraw/html ins","url":"sketch/redraw/html.html#ins"},{"doc":"sketch/redraw/html","title":"kbd","content":"pub fn kbd(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.kbd\nsketch/redraw/html kbd","url":"sketch/redraw/html.html#kbd"},{"doc":"sketch/redraw/html","title":"label","content":"pub fn label(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.label\nsketch/redraw/html label","url":"sketch/redraw/html.html#label"},{"doc":"sketch/redraw/html","title":"legend","content":"pub fn legend(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.legend\nsketch/redraw/html legend","url":"sketch/redraw/html.html#legend"},{"doc":"sketch/redraw/html","title":"li","content":"pub fn li(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.li\nsketch/redraw/html li","url":"sketch/redraw/html.html#li"},{"doc":"sketch/redraw/html","title":"link","content":"pub fn link(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.link\nsketch/redraw/html link","url":"sketch/redraw/html.html#link"},{"doc":"sketch/redraw/html","title":"main","content":"pub fn main(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.main\nsketch/redraw/html main","url":"sketch/redraw/html.html#main"},{"doc":"sketch/redraw/html","title":"map","content":"pub fn map(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.map\nsketch/redraw/html map","url":"sketch/redraw/html.html#map"},{"doc":"sketch/redraw/html","title":"mark","content":"pub fn mark(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.mark\nsketch/redraw/html mark","url":"sketch/redraw/html.html#mark"},{"doc":"sketch/redraw/html","title":"menu","content":"pub fn menu(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.menu\nsketch/redraw/html menu","url":"sketch/redraw/html.html#menu"},{"doc":"sketch/redraw/html","title":"meta","content":"pub fn meta(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.meta\nsketch/redraw/html meta","url":"sketch/redraw/html.html#meta"},{"doc":"sketch/redraw/html","title":"meter","content":"pub fn meter(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.meter\nsketch/redraw/html meter","url":"sketch/redraw/html.html#meter"},{"doc":"sketch/redraw/html","title":"nav","content":"pub fn nav(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.nav\nsketch/redraw/html nav","url":"sketch/redraw/html.html#nav"},{"doc":"sketch/redraw/html","title":"noscript","content":"pub fn noscript(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.noscript\nsketch/redraw/html noscript","url":"sketch/redraw/html.html#noscript"},{"doc":"sketch/redraw/html","title":"object","content":"pub fn object(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.object\nsketch/redraw/html object","url":"sketch/redraw/html.html#object"},{"doc":"sketch/redraw/html","title":"ol","content":"pub fn ol(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.ol\nsketch/redraw/html ol","url":"sketch/redraw/html.html#ol"},{"doc":"sketch/redraw/html","title":"optgroup","content":"pub fn optgroup(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.optgroup\nsketch/redraw/html optgroup","url":"sketch/redraw/html.html#optgroup"},{"doc":"sketch/redraw/html","title":"option","content":"pub fn option(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.option\nsketch/redraw/html option","url":"sketch/redraw/html.html#option"},{"doc":"sketch/redraw/html","title":"output","content":"pub fn output(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.output\nsketch/redraw/html output","url":"sketch/redraw/html.html#output"},{"doc":"sketch/redraw/html","title":"p","content":"pub fn p(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.p\nsketch/redraw/html p","url":"sketch/redraw/html.html#p"},{"doc":"sketch/redraw/html","title":"picture","content":"pub fn picture(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.picture\nsketch/redraw/html picture","url":"sketch/redraw/html.html#picture"},{"doc":"sketch/redraw/html","title":"pre","content":"pub fn pre(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.pre\nsketch/redraw/html pre","url":"sketch/redraw/html.html#pre"},{"doc":"sketch/redraw/html","title":"progress","content":"pub fn progress(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.progress\nsketch/redraw/html progress","url":"sketch/redraw/html.html#progress"},{"doc":"sketch/redraw/html","title":"q","content":"pub fn q(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.q\nsketch/redraw/html q","url":"sketch/redraw/html.html#q"},{"doc":"sketch/redraw/html","title":"rp","content":"pub fn rp(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.rp\nsketch/redraw/html rp","url":"sketch/redraw/html.html#rp"},{"doc":"sketch/redraw/html","title":"rt","content":"pub fn rt(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.rt\nsketch/redraw/html rt","url":"sketch/redraw/html.html#rt"},{"doc":"sketch/redraw/html","title":"ruby","content":"pub fn ruby(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.ruby\nsketch/redraw/html ruby","url":"sketch/redraw/html.html#ruby"},{"doc":"sketch/redraw/html","title":"s","content":"pub fn s(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.s\nsketch/redraw/html s","url":"sketch/redraw/html.html#s"},{"doc":"sketch/redraw/html","title":"samp","content":"pub fn samp(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.samp\nsketch/redraw/html samp","url":"sketch/redraw/html.html#samp"},{"doc":"sketch/redraw/html","title":"script","content":"pub fn script(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.script\nsketch/redraw/html script","url":"sketch/redraw/html.html#script"},{"doc":"sketch/redraw/html","title":"section","content":"pub fn section(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.section\nsketch/redraw/html section","url":"sketch/redraw/html.html#section"},{"doc":"sketch/redraw/html","title":"select","content":"pub fn select(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.select\nsketch/redraw/html select","url":"sketch/redraw/html.html#select"},{"doc":"sketch/redraw/html","title":"slot","content":"pub fn slot(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.slot\nsketch/redraw/html slot","url":"sketch/redraw/html.html#slot"},{"doc":"sketch/redraw/html","title":"small","content":"pub fn small(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.small\nsketch/redraw/html small","url":"sketch/redraw/html.html#small"},{"doc":"sketch/redraw/html","title":"source","content":"pub fn source(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.source\nsketch/redraw/html source","url":"sketch/redraw/html.html#source"},{"doc":"sketch/redraw/html","title":"span","content":"pub fn span(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.span\nsketch/redraw/html span","url":"sketch/redraw/html.html#span"},{"doc":"sketch/redraw/html","title":"strong","content":"pub fn strong(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.strong\nsketch/redraw/html strong","url":"sketch/redraw/html.html#strong"},{"doc":"sketch/redraw/html","title":"style","content":"pub fn style(\n  styles: Class,\n  attrs: List(Attribute),\n  content: String,\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.style\nsketch/redraw/html style","url":"sketch/redraw/html.html#style"},{"doc":"sketch/redraw/html","title":"sub","content":"pub fn sub(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.sub\nsketch/redraw/html sub","url":"sketch/redraw/html.html#sub"},{"doc":"sketch/redraw/html","title":"summary","content":"pub fn summary(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.summary\nsketch/redraw/html summary","url":"sketch/redraw/html.html#summary"},{"doc":"sketch/redraw/html","title":"sup","content":"pub fn sup(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.sup\nsketch/redraw/html sup","url":"sketch/redraw/html.html#sup"},{"doc":"sketch/redraw/html","title":"table","content":"pub fn table(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.table\nsketch/redraw/html table","url":"sketch/redraw/html.html#table"},{"doc":"sketch/redraw/html","title":"tbody","content":"pub fn tbody(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.tbody\nsketch/redraw/html tbody","url":"sketch/redraw/html.html#tbody"},{"doc":"sketch/redraw/html","title":"td","content":"pub fn td(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.td\nsketch/redraw/html td","url":"sketch/redraw/html.html#td"},{"doc":"sketch/redraw/html","title":"template","content":"pub fn template(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.template\nsketch/redraw/html template","url":"sketch/redraw/html.html#template"},{"doc":"sketch/redraw/html","title":"textarea","content":"pub fn textarea(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.textarea\nsketch/redraw/html textarea","url":"sketch/redraw/html.html#textarea"},{"doc":"sketch/redraw/html","title":"tfoot","content":"pub fn tfoot(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.tfoot\nsketch/redraw/html tfoot","url":"sketch/redraw/html.html#tfoot"},{"doc":"sketch/redraw/html","title":"th","content":"pub fn th(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.th\nsketch/redraw/html th","url":"sketch/redraw/html.html#th"},{"doc":"sketch/redraw/html","title":"thead","content":"pub fn thead(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.thead\nsketch/redraw/html thead","url":"sketch/redraw/html.html#thead"},{"doc":"sketch/redraw/html","title":"time","content":"pub fn time(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.time\nsketch/redraw/html time","url":"sketch/redraw/html.html#time"},{"doc":"sketch/redraw/html","title":"title","content":"pub fn title(\n  styles: Class,\n  attrs: List(Attribute),\n  content: String,\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.title\nsketch/redraw/html title","url":"sketch/redraw/html.html#title"},{"doc":"sketch/redraw/html","title":"tr","content":"pub fn tr(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.tr\nsketch/redraw/html tr","url":"sketch/redraw/html.html#tr"},{"doc":"sketch/redraw/html","title":"track","content":"pub fn track(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.track\nsketch/redraw/html track","url":"sketch/redraw/html.html#track"},{"doc":"sketch/redraw/html","title":"u","content":"pub fn u(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.u\nsketch/redraw/html u","url":"sketch/redraw/html.html#u"},{"doc":"sketch/redraw/html","title":"ul","content":"pub fn ul(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.ul\nsketch/redraw/html ul","url":"sketch/redraw/html.html#ul"},{"doc":"sketch/redraw/html","title":"var","content":"pub fn var(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.var\nsketch/redraw/html var","url":"sketch/redraw/html.html#var"},{"doc":"sketch/redraw/html","title":"video","content":"pub fn video(\n  styles: Class,\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.video\nsketch/redraw/html video","url":"sketch/redraw/html.html#video"},{"doc":"sketch/redraw/html","title":"wbr","content":"pub fn wbr(styles: Class, attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nsketch/redraw/html.wbr\nsketch/redraw/html wbr","url":"sketch/redraw/html.html#wbr"},{"doc":"sketch/redraw/html","title":"sketch/redraw/html","content":"","url":"sketch/redraw/html.html"}]);